@@ -226,6 +226,7 @@ DiscoverObject::DiscoverObject(const QVariantMap &initialProperties)
 
 DiscoverObject::~DiscoverObject()
 {
+    m_isDeleting = true;
     m_engine->deleteLater();
 }
 
@@ -371,6 +372,9 @@ void DiscoverObject::openApplication(const QUrl &url)
                     connect(timeout, &QTimer::timeout, timeout, &QTimer::deleteLater);
 
                     auto openResourceOrWait = [this, res, timeout] {
+                        if (m_isDeleting) {
+                            return false;
+                        }
                         auto idx = kIndexOf(res, [](auto res) {
                             return res.resource->isInstalled();
                         });
@@ -660,8 +664,13 @@ void DiscoverObject::setAboutToReboot()
     }
 }
 
+Q_GLOBAL_STATIC_WITH_ARGS(const bool, s_weAreOnPlasma, (qgetenv("XDG_CURRENT_DESKTOP") == "KDE"))
+
 void DiscoverObject::promptReboot()
 {
+    if (!s_weAreOnPlasma) {
+        qCWarning(DISCOVER_LOG) << "Cannot prompt for reboot outside of Plasma";
+    }
     auto method = QDBusMessage::createMethodCall(QStringLiteral("org.kde.LogoutPrompt"),
                                                  QStringLiteral("/LogoutPrompt"),
                                                  QStringLiteral("org.kde.LogoutPrompt"),
@@ -672,12 +681,21 @@ void DiscoverObject::promptReboot()
 void DiscoverObject::rebootNow()
 {
     setAboutToReboot();
-    auto method = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.login1"),
-                                                 QStringLiteral("/org/freedesktop/login1"),
-                                                 QStringLiteral("org.freedesktop.login1.Manager"),
-                                                 QStringLiteral("Reboot"));
-    method.setArguments({true /*interactive*/});
-    QDBusConnection::systemBus().asyncCall(method);
+
+    QDBusMessage method;
+    if (s_weAreOnPlasma) {
+        method = QDBusMessage::createMethodCall(QStringLiteral("org.kde.Shutdown"),
+                                                QStringLiteral("/Shutdown"),
+                                                QStringLiteral("org.kde.Shutdown"),
+                                                QStringLiteral("logoutAndReboot"));
+    } else {
+        method = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.login1"),
+                                                QStringLiteral("/org/freedesktop/login1"),
+                                                QStringLiteral("org.freedesktop.login1.Manager"),
+                                                QStringLiteral("Reboot"));
+        method.setArguments({true /*interactive*/});
+    }
+    QDBusConnection::sessionBus().asyncCall(method);
 }
 
 void DiscoverObject::shutdownNow()
@@ -691,12 +709,20 @@ void DiscoverObject::shutdownNow()
     }
     setAboutToPowerOff();
 
-    auto method = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.login1"),
-                                                 QStringLiteral("/org/freedesktop/login1"),
-                                                 QStringLiteral("org.freedesktop.login1.Manager"),
-                                                 shouldRebootFirst ? QStringLiteral("Reboot") : QStringLiteral("PowerOff"));
-    method.setArguments({true /*interactive*/});
-    QDBusConnection::systemBus().asyncCall(method);
+    QDBusMessage method;
+    if (s_weAreOnPlasma) {
+        auto method = QDBusMessage::createMethodCall(QStringLiteral("org.kde.Shutdown"),
+                                                     QStringLiteral("/Shutdown"),
+                                                     QStringLiteral("org.kde.Shutdown"),
+                                                     shouldRebootFirst ? QStringLiteral("logoutAndReboot") : QStringLiteral("logoutAndShutdown"));
+    } else {
+        method = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.login1"),
+                                                QStringLiteral("/org/freedesktop/login1"),
+                                                QStringLiteral("org.freedesktop.login1.Manager"),
+                                                shouldRebootFirst ? QStringLiteral("Reboot") : QStringLiteral("PowerOff"));
+        method.setArguments({true /*interactive*/});
+    }
+    QDBusConnection::sessionBus().asyncCall(method);
 }
 
 QString DiscoverObject::describeSources() const
