@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef PACKAGESTATE_H
-#define PACKAGESTATE_H
+#pragma once
 
 #include "discovercommon_export.h"
 #include <QString>
@@ -20,7 +19,7 @@ class DISCOVERCOMMON_EXPORT PackageState
 public:
     PackageState(QString packageName, QString name, QString description, bool installed);
     PackageState(const QString &name, const QString &description, bool installed);
-    PackageState &operator=(const PackageState &other);
+    PackageState(const PackageState &ps);
 
     QString packageName() const;
     QString name() const;
@@ -29,12 +28,10 @@ public:
     void setInstalled(bool installed);
 
 private:
-    const QString m_packageName;
-    const QString m_name;
-    const QString m_description;
+    QString m_packageName;
+    QString m_name;
+    QString m_description;
     bool m_installed;
 };
 
 DISCOVERCOMMON_EXPORT QDebug operator<<(QDebug dbg, const PackageState &state);
-
-#endif // PACKAGESTATE_H
